@@ -196,14 +196,14 @@ static void        xfce_bg_set_placement    (XfceBG           *bg,
 static void        xfce_bg_set_filename     (XfceBG           *bg,
                                              const char       *filename);
 
-static void        color_from_array         (XfconfChannel    *channel,
+static void        color_from_rgba_array    (XfconfChannel    *channel,
                                              const gchar      *property,
                                              GdkRGBA          *colorp)
 {
     gdouble r, g, b, a;
 
-    /* If all else fails use black */
-    gdk_rgba_parse (colorp, "#000000");
+    /* If all else fails use Xfdesktop's default */
+    gdk_rgba_parse (colorp, "#152233");
 
     if (!xfconf_channel_has_property (channel, property))
         return;
@@ -222,6 +222,32 @@ static void        color_from_array         (XfconfChannel    *channel,
     colorp->alpha = a;
 }
 
+static void        color_from_color_array   (XfconfChannel    *channel,
+                                             const gchar      *property,
+                                             GdkRGBA          *colorp)
+{
+    guint   rc, gc, bc, ac;
+
+    /* If all else fails use Xfdesktop's default */
+    gdk_rgba_parse (colorp, "#152233");
+
+    if (!xfconf_channel_has_property (channel, property))
+        return;
+
+    xfconf_channel_get_array(channel,
+                             property,
+                             G_TYPE_UINT, &rc,
+                             G_TYPE_UINT, &gc,
+                             G_TYPE_UINT, &bc,
+                             G_TYPE_UINT, &ac,
+                             G_TYPE_INVALID);
+
+    colorp->red = (gdouble) rc / 65535;
+    colorp->green = (gdouble) gc / 65535;
+    colorp->blue = (gdouble) bc / 65535;
+    colorp->alpha = (gdouble) ac / 65535;
+}
+
 static gboolean
 do_changed (XfceBG *bg)
 {
@@ -387,10 +413,9 @@ xfce_bg_load_from_xfconf (XfceBG        *bg,
     GdkMonitor      *mon;
     const gchar     *monitor_name;
     gchar           *prop_prefix;
-    gchar           *property;
+    gchar           *property, *property2;
 
     g_return_if_fail(XFCE_IS_BG(bg));
-    //g_return_if_fail (G_IS_SETTINGS (settings));
 
     if (monitor == NULL)
     {
@@ -453,16 +478,35 @@ xfce_bg_load_from_xfconf (XfceBG        *bg,
 
     /* Colors */
     g_free(property);
-    property = g_strconcat(prop_prefix, "/workspace0/rgba1", NULL);
-    color_from_array(channel, property, &c1);
+    property = g_strconcat(prop_prefix, "/rgba1", NULL);
+    property2 = g_strconcat(prop_prefix, "/color1", NULL);
+    if (!xfconf_channel_has_property (channel, property) && xfconf_channel_has_property (channel, property2)) {
+        // Using GdkColor properties from Xfdesktop 4.12
+        g_free(property);
+        g_free(property2);
 
-    g_free(property);
-    property = g_strconcat(prop_prefix, "/workspace0/rgba2", NULL);
-    color_from_array(channel, property, &c2);
+        property = g_strconcat(prop_prefix, "/color1", NULL);
+        color_from_color_array(channel, property, &c1);
+
+        g_free(property);
+        property = g_strconcat(prop_prefix, "/color2", NULL);
+        color_from_color_array(channel, property, &c2);
+    } else {
+        // Using GdkRGBA properties from Xfdesktop 4.13
+        g_free(property);
+        g_free(property2);
+
+        property = g_strconcat(prop_prefix, "/rgba1", NULL);
+        color_from_rgba_array(channel, property, &c1);
+
+        g_free(property);
+        property = g_strconcat(prop_prefix, "/rgba2", NULL);
+        color_from_rgba_array(channel, property, &c2);
+    }
 
     /* Color type */
     g_free(property);
-    property = g_strconcat(prop_prefix, "/workspace0/color-style", NULL);
+    property = g_strconcat(prop_prefix, "/color-style", NULL);
     ctype = xfconf_channel_get_int(channel, property, XFCE_BG_COLOR_SOLID);
 
     g_free(property);
@@ -976,7 +1020,7 @@ xfce_bg_draw (XfceBG    *bg,
         return;
 
     draw_color (bg, dest);
-    if (bg->filename) {
+    if (bg->filename && bg->placement != XFCE_BG_PLACEMENT_NONE) {
         draw_once (bg, dest);
     }
 }
