@@ -33,6 +33,7 @@
 
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+#include <gtk/gtkx.h>
 
 #include <gio/gio.h>
 
@@ -48,9 +49,9 @@
 #include "gs-job.h"
 #include "gs-prefs.h" /* for GS_MODE enum */
 
-#include <xfconf/xfconf.h>
+#include "xfce4-screensaver-preferences-ui.h"
 
-#define GTK_BUILDER_FILE "xfce4-screensaver-preferences.ui"
+#include <xfconf/xfconf.h>
 
 #define GPM_COMMAND "xfce4-power-manager-settings"
 
@@ -79,6 +80,13 @@ static GSThemeManager *theme_manager = NULL;
 static GSJob          *job = NULL;
 static XfconfChannel  *screensaver_channel = NULL;
 
+static gint opt_socket_id = 0;
+static GOptionEntry entries[] =
+{
+    { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &opt_socket_id, N_("Settings manager socket"), N_("SOCKET ID") },
+    { NULL }
+};
+
 static gint32
 config_get_activate_delay (gboolean *is_writable)
 {
@@ -1279,15 +1287,63 @@ static void
 setup_for_root_user (void)
 {
     GtkWidget *lock_checkbox;
-    GtkWidget *label;
+    GtkWidget *infobar;
 
     lock_checkbox = GTK_WIDGET (gtk_builder_get_object (builder, "lock_checkbox"));
-    label = GTK_WIDGET (gtk_builder_get_object (builder, "root_warning_label"));
+    infobar = GTK_WIDGET (gtk_builder_get_object (builder, "root_warning_infobar"));
 
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (lock_checkbox), FALSE);
     gtk_widget_set_sensitive (lock_checkbox, FALSE);
 
-    gtk_widget_show (label);
+    gtk_widget_show (infobar);
+}
+
+static void
+resolve_lid_switch_cb (GtkWidget *widget,
+                       gpointer   user_data)
+{
+    XfconfChannel *channel = xfconf_channel_get("xfce4-power-manager");
+    const gchar   *property = "/xfce4-power-manager/logind-handle-lid-switch";
+    gboolean       locked = xfconf_channel_is_property_locked(channel, property);
+    GtkWidget     *infobar = GTK_WIDGET (gtk_builder_get_object (builder, "logind_lid_infobar"));
+
+    if (!locked)
+    {
+        xfconf_channel_set_bool(channel, property, FALSE);
+        gtk_widget_hide (GTK_WIDGET (infobar));
+    }
+}
+
+static void
+setup_for_lid_switch (void)
+{
+    XfconfChannel *channel = xfconf_channel_get ("xfce4-power-manager");
+    const gchar   *property = "/xfce4-power-manager/logind-handle-lid-switch";
+    gboolean       handled = xfconf_channel_get_bool (channel, property, FALSE);
+    gboolean       locked = xfconf_channel_is_property_locked (channel, property);
+    GtkWidget     *infobar;
+    GtkWidget     *button;
+
+    infobar = GTK_WIDGET (gtk_builder_get_object (builder, "logind_lid_infobar"));
+    button = GTK_WIDGET (gtk_builder_get_object (builder, "logind_lid_resolve"));
+
+    if (handled)
+    {
+        gtk_widget_show (infobar);
+        if (locked)
+        {
+            gtk_widget_hide (button);
+        }
+        else
+        {
+            gtk_widget_show (button);
+            g_signal_connect (button, "clicked", G_CALLBACK (resolve_lid_switch_cb), NULL);
+        }
+    }
+    else
+    {
+        gtk_widget_hide (infobar);
+    }
 }
 
 /* copied from gs-window-x11.c */
@@ -1467,9 +1523,10 @@ is_program_in_path (const char *program)
 }
 
 static void
-init_capplet (void)
+configure_capplet (void)
 {
     GtkWidget *dialog;
+    GtkWidget *plug_child;
     GtkWidget *preview;
     GtkWidget *treeview;
     GtkWidget *list_scroller;
@@ -1478,7 +1535,7 @@ init_capplet (void)
     GtkWidget *label;
     GtkWidget *enabled_checkbox;
     GtkWidget *lock_checkbox;
-    GtkWidget *root_warning_label;
+    GtkWidget *root_warning_infobar;
     GtkWidget *preview_button;
     GtkWidget *gpm_button;
     GtkWidget *fullscreen_preview_window;
@@ -1486,21 +1543,19 @@ init_capplet (void)
     GtkWidget *fullscreen_preview_previous;
     GtkWidget *fullscreen_preview_next;
     GtkWidget *fullscreen_preview_close;
-    char      *gtk_builder_file;
     gdouble    activate_delay;
     gboolean   enabled;
     gboolean   is_writable;
     GError    *error=NULL;
     gint       mode;
 
-    gtk_builder_file = g_build_filename (GTKBUILDERDIR, GTK_BUILDER_FILE, NULL);
     builder = gtk_builder_new();
-    if (!gtk_builder_add_from_file(builder, gtk_builder_file, &error))
+    if (!gtk_builder_add_from_string (builder, xfce4_screensaver_preferences_ui,
+                                      xfce4_screensaver_preferences_ui_length, &error))
     {
-        g_warning("Couldn't load builder file: %s", error->message);
+        g_warning ("Error loading UI: %s", error->message);
         g_error_free(error);
     }
-    g_free (gtk_builder_file);
 
     if (builder == NULL)
     {
@@ -1521,13 +1576,14 @@ init_capplet (void)
 
     preview                     = GTK_WIDGET (gtk_builder_get_object (builder, "preview_area"));
     dialog                      = GTK_WIDGET (gtk_builder_get_object (builder, "prefs_dialog"));
+    plug_child                  = GTK_WIDGET (gtk_builder_get_object (builder, "plug-child"));
     treeview                    = GTK_WIDGET (gtk_builder_get_object (builder, "savers_treeview"));
     list_scroller               = GTK_WIDGET (gtk_builder_get_object (builder, "themes_scrolled_window"));
     activate_delay_hscale       = GTK_WIDGET (gtk_builder_get_object (builder, "activate_delay_hscale"));
     activate_delay_hbox         = GTK_WIDGET (gtk_builder_get_object (builder, "activate_delay_hbox"));
     enabled_checkbox            = GTK_WIDGET (gtk_builder_get_object (builder, "enable_checkbox"));
     lock_checkbox               = GTK_WIDGET (gtk_builder_get_object (builder, "lock_checkbox"));
-    root_warning_label          = GTK_WIDGET (gtk_builder_get_object (builder, "root_warning_label"));
+    root_warning_infobar        = GTK_WIDGET (gtk_builder_get_object (builder, "root_warning_infobar"));
     preview_button              = GTK_WIDGET (gtk_builder_get_object (builder, "preview_button"));
     gpm_button                  = GTK_WIDGET (gtk_builder_get_object (builder, "gpm_button"));
     fullscreen_preview_window   = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_window"));
@@ -1541,7 +1597,7 @@ init_capplet (void)
     label = GTK_WIDGET (gtk_builder_get_object (builder, "savers_label"));
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), treeview);
 
-    gtk_widget_set_no_show_all (root_warning_label, TRUE);
+    gtk_widget_set_no_show_all (root_warning_infobar, TRUE);
     widget_set_best_visual (preview);
 
     if (! is_program_in_path (GPM_COMMAND))
@@ -1591,25 +1647,22 @@ init_capplet (void)
                       "draw", G_CALLBACK (preview_on_draw),
                       NULL);
 
-    gtk_drag_dest_set (dialog, GTK_DEST_DEFAULT_ALL,
+    gtk_drag_dest_set (plug_child, GTK_DEST_DEFAULT_ALL,
                        drop_types, G_N_ELEMENTS (drop_types),
                        GDK_ACTION_COPY | GDK_ACTION_LINK | GDK_ACTION_MOVE);
 
-    g_signal_connect (dialog, "drag-motion",
+    g_signal_connect (plug_child, "drag-motion",
                       G_CALLBACK (drag_motion_cb), NULL);
-    g_signal_connect (dialog, "drag-leave",
+    g_signal_connect (plug_child, "drag-leave",
                       G_CALLBACK (drag_leave_cb), NULL);
-    g_signal_connect (dialog, "drag-data-received",
+    g_signal_connect (plug_child, "drag-data-received",
                       G_CALLBACK (drag_data_received_cb), NULL);
 
-    gtk_widget_show_all (dialog);
-
     /* Update list of themes if using random screensaver */
     mode = xfconf_channel_get_int (screensaver_channel, KEY_MODE, DEFAULT_KEY_MODE);
     if (mode == GS_MODE_RANDOM) {
         gchar **list;
         list = get_all_theme_ids (theme_manager);
-        g_warning("instance b");
         xfconf_channel_set_string_list (screensaver_channel, KEY_THEMES, (const gchar * const*) list);
         g_strfreev (list);
     }
@@ -1617,6 +1670,8 @@ init_capplet (void)
     g_signal_connect (preview, "draw", G_CALLBACK (preview_on_draw), NULL);
     gs_job_set_widget (job, preview);
 
+    setup_for_lid_switch ();
+
     if (check_is_root_user ())
     {
         setup_for_root_user ();
@@ -1625,9 +1680,6 @@ init_capplet (void)
     g_signal_connect (activate_delay_hscale, "value-changed",
                       G_CALLBACK (activate_delay_value_changed_cb), NULL);
 
-    g_signal_connect (dialog, "response",
-                      G_CALLBACK (response_cb), NULL);
-
     g_signal_connect (preview_button, "clicked",
                       G_CALLBACK (fullscreen_preview_start_cb),
                       treeview);
@@ -1652,7 +1704,9 @@ int
 main (int    argc,
       char **argv)
 {
-    GError *error = NULL;
+    GtkWidget *plug;
+    GObject   *plug_child;
+    GError    *error = NULL;
 
 #ifdef ENABLE_NLS
     bindtextdomain (GETTEXT_PACKAGE, XFCELOCALEDIR);
@@ -1662,7 +1716,21 @@ main (int    argc,
     textdomain (GETTEXT_PACKAGE);
 #endif
 
-    gtk_init (&argc, &argv);
+    if (!gtk_init_with_args (&argc, &argv, "", entries, NULL, &error))
+    {
+        if (G_LIKELY (error))
+        {
+            /* print error */
+            g_error ("%s\n", error->message);
+            g_error_free (error);
+        }
+        else
+        {
+            g_error ("Unable to open display.");
+        }
+
+        return EXIT_FAILURE;
+    }
 
     /* hook to make sure the libxfce4ui library is linked */
     if (xfce_titled_dialog_get_type() == 0)
@@ -1679,9 +1747,43 @@ main (int    argc,
     job = gs_job_new ();
     theme_manager = gs_theme_manager_new ();
 
-    init_capplet ();
+    configure_capplet ();
 
-    gtk_main ();
+    if (G_UNLIKELY(opt_socket_id == 0))
+    {
+        GtkWidget *dialog = GTK_WIDGET (gtk_builder_get_object (builder, "prefs_dialog"));
+
+        g_signal_connect(dialog, "response",
+                         G_CALLBACK(response_cb), NULL);
+
+        gtk_widget_show_all (dialog);
+
+        /* To prevent the settings dialog to be saved in the session */
+        gdk_x11_set_sm_client_id("FAKE ID");
+
+        gtk_main();
+    }
+    else
+    {
+        /* Create plug widget */
+        plug = gtk_plug_new(opt_socket_id);
+        g_signal_connect(plug, "delete-event", G_CALLBACK(gtk_main_quit), NULL);
+        gtk_widget_show(plug);
+
+        /* Stop startup notification */
+        gdk_notify_startup_complete();
+
+        /* Get plug child widget */
+        plug_child = gtk_builder_get_object (builder, "plug-child");
+        xfce_widget_reparent (GTK_WIDGET(plug_child), plug);
+        gtk_widget_show_all (GTK_WIDGET(plug_child));
+
+        /* To prevent the settings dialog to be saved in the session */
+        gdk_x11_set_sm_client_id("FAKE ID");
+
+        /* Enter main loop */
+        gtk_main();
+    }
 
     finalize_capplet ();
 
